@@ -1,10 +1,11 @@
 from abc import abstractmethod
 
 from api.handler.IKillableScript import IKillableScript
+from api.handler.ILogAbleHandler import ILogAbleHandler
 from api.model.FdInputPipe import FdInputPipe
 
 
-class ISimpleScriptCE(IKillableScript):
+class ISimpleScriptCE(IKillableScript,ILogAbleHandler):
     """
     Python脚本式的CE的基类
     """
