@@ -10,7 +10,7 @@ class ISampleScriptCrawl(ISimpleScriptCrawl):
     """
 
     @abstractmethod
-    def do_crawl(params:dict):
+    def do_crawl(self,params:dict):
         """
         抓取的业务逻辑
         :return: 返回一个 OutputWrapper的 数组
