@@ -1,9 +1,10 @@
 from abc import abstractmethod
 
 from api.handler.IKillableScript import IKillableScript
+from api.handler.ILogAbleHandler import ILogAbleHandler
 
 
-class ISimpleScriptCrawl(IKillableScript):
+class ISimpleScriptCrawl(IKillableScript,ILogAbleHandler):
 
     """
     Python脚本式的Crawl的基类
@@ -14,5 +15,4 @@ class ISimpleScriptCrawl(IKillableScript):
         """
         抓取的业务逻辑
         :return: 返回一个 OutputWrapper的 数组
-        """
-        pass
\ No newline at end of file
+        """
\ No newline at end of file
